# Mahalanobis

This package can be used for calculating distances between data points and a reference distribution according to the Mahalanobis distance algorithm. The algorithm can be seen as a generalization of the euclidean distance, but normalizing the calculated distance with the variance of the points distribution used as fingerprint.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

This package works with Python 3 onwards as it uses f-strings

### Installing

```
pip install mahalanobis
```

End with an example of getting some data out of the system or using it for a little demo

## Testing

pytest is used as testing framework

## Authors

* **Daniel Moseguí González** - *Initial work* - [mosegui](https://github.com/mosegui)

## License

This project is licensed under the GNU GPL License - see the [LICENSE](LICENSE) file for details